#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date: 2017-12-20
#
# Check_MK checkpoint_identity_awareness WATO plugin
#
# 2022-11-29: fixed CheckParameterRulespecWithoutItem
#             (from CheckParameterRulespecWithItem) THX to jblaak[at]gmail[dot]com
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    ListChoice,
)

from cmk.gui.plugins.wato.utils import (
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
    CheckParameterRulespecWithoutItem
)

_ignorecounters = [
    # ('iaAuthUsers', 'Authenticated users and machines'),  # will be used in perf-o-meter
    ('iaAuthUsersPass', 'Authenticated users by name and password'),
    ('iaAuthUsersADQuery', 'Authenticated users by ADQuery'),
    ('iaAuthUsersKerberos', 'Authenticated users by Kerberos'),
    ('iaAuthMachKerberos', 'Authenticated machines by Kerberos'),
    ('iaAuthMachADQuery', 'Authenticated machines by ADQuery'),
    # ('iaUnAuthUsers', 'Unauthenticated guests'),  # will be used in perf-o-meter
    ('iaLoggedInAgent', 'Logged in users with agents'),
    ('iaLoggedInCaptivePortal', 'Logged in users with Captive Portal'),
    ('iaLoggedInADQuery', 'Logged in users with ADQuery'),

    ('iaRADIUSAccounting', 'Identities logged in with RADIUS Accounting'),
    ('iaIdentityCollectorActiveDirectory', 'Identities logged in with Identity Collector Active Directory'),
    ('iaIdentityCollectorCiscoISE', 'Identities logged in with Identity Collector Cisco ISE'),
    ('iaTerminalServer', 'Identities logged in with terminal server'),
    ('iaRemoteAccess', 'Identities logged in with Remote Access'),
    ('iaIdentityWebAPI', 'Identities logged in with Identity Web API'),

    ('iaSuccUserLoginPass', 'Successfull login attempts users by name and password'),
    ('iaSuccUserLoginKerberos', 'Successfull login attempts users by Kerberos'),
    ('iaSuccUserLoginADQuery', 'Successfull login attempts users by ADQuery'),
    ('iaSuccMachLoginKerberos', 'Successfull login attempts machines by Kerberos'),
    ('iaSuccMachLoginADQuery', 'Successfull login attempts machines by ADQuery'),
    ('iaUnSuccUserLoginPass', 'Unsuccessfull login attempts users by name and password'),
    ('iaUnSuccUserLoginKerberos', 'Unsuccessfull login attempts users by Kerberos'),
    ('iaUnSuccMachLoginKerberos', 'Unsuccessfull login attempts machines by Kerberos'),
    ('iaSuccUserLDAP', 'LDAP queries successfull'),
    ('iaUnSuccUserLDAP', 'LDAP queries unsuccessfull'),
    ('iaAntiSpoffProtection', 'Users with an active Traffic Anti-Spoffing protection'),
    ('iaDataTrans', 'How much data did the gateway transmitted'),
]


def _parameter_valuespec_checkpoint_identity_awareness():
    return Dictionary(
        title=_('Check Point Identity Awareness status'),
        elements=[
            (
                'ignore_counters',
                ListChoice(
                    title=_('list of counters to ignore'),
                    help=_('Counters to remove from performance data.'),
                    choices=_ignorecounters,
                    default_value=[],
                )
            ),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_identity_awareness',
        group=RulespecGroupCheckParametersNetworking,
        # match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_identity_awareness,
        title=lambda: _('Check Point Identity Awareness'),
    )
)
